# safir-arq

safir-arq is a subpackage of Safir, Rubin Observatory's library for building [FastAPI](https://fastapi.tiangolo.com/) services for the [Phalanx](https://phalanx.lsst.io) Kubernetes clusters, including the Rubin Science Platform and Roundtable.
It is a separate PyPI module so that it can be used as a dependency in contexts where the full Safir dependency is undesirable.

safir-arq is available from [PyPI](https://pypi.org/project/safir-arq/):

```sh
pip install safir-arq
```

safir-arq is developed and tested in conjunction with Safir.
Read more about Safir at https://safir.lsst.io.
